# Changelog

## 0.0.1 (2017-04-27)

- This is the initial release. It provides rapid sky localization with
  BAYESTAR, sky map annotation, and sending mock alerts.

- By default, GWCelery is configured to listen to the test LVAlert server.

- Sending VOEvents to GCN/TAN is disabled for now.
